Skip to content

The template for benchmarks/custom_bms/install.py has been updated #6385

New issue

Have a question about this project? Sign up for a free GitHub account to open an issue and contact its maintainers and the community.

By clicking “Sign up for GitHub”, you agree to our terms of service and privacy statement. We’ll occasionally send you account related emails.

Already on GitHub? Sign in to your account

Closed
scitools-ci bot opened this issue Mar 27, 2025 · 1 comment
Closed

The template for benchmarks/custom_bms/install.py has been updated #6385

scitools-ci bot opened this issue Mar 27, 2025 · 1 comment
Labels
Bot A bot generated issue/pull-request Type: Infrastructure

Comments

@scitools-ci
Copy link
Contributor

scitools-ci bot commented Mar 27, 2025

The template for benchmarks/custom_bms/install.py has been updated.

Consider adopting these changes into the repo; the changes can be found below.

The template file can be found in the .github repo: templates/benchmarks/custom_bms/install.py

The diff between the specified file is as follows:

diff --git a/templates/benchmarks/custom_bms/install.py b/templates/benchmarks/custom_bms/install.py
index 59757ba..f762ee9 100644
--- a/templates/benchmarks/custom_bms/install.py
+++ b/templates/benchmarks/custom_bms/install.py
@@ -17,17 +17,17 @@ this_dir = Path(__file__).parent
 
 
 def package_files(new_dir: Path) -> None:
     """Package REPONAME's custom benchmarks for detection by ASV.
 
     Parameters
     ----------
     new_dir : Path
         The directory to package the custom benchmarks in.
     """
-    asv_bench_REPONAME = new_dir / "asv_bench_REPONAME"
-    benchmarks = asv_bench_REPONAME / "benchmarks"
+    asv_bench_scitools = new_dir / "asv_bench_scitools"
+    benchmarks = asv_bench_scitools / "benchmarks"
     benchmarks.mkdir(parents=True)
-    (asv_bench_REPONAME / "__init__.py").touch()
+    (asv_bench_scitools / "__init__.py").touch()
 
     for py_file in this_dir.glob("*.py"):
         if py_file != Path(__file__):
@@ -39,7 +39,7 @@ def package_files(new_dir: Path) -> None:
     py_project.write_text(
         """
         [project]
-        name = "asv_bench_REPONAME"
+        name = "asv_bench_scitools"
         version = "0.1"
         """
     )
@@ -52,4 +52,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
@scitools-ci scitools-ci bot added Bot A bot generated issue/pull-request Type: Infrastructure labels Mar 27, 2025
@pp-mo pp-mo added Type: Bug and removed Type: Bug labels Mar 28, 2025
@trexfeathers
@@ -17,17 +17,17 @@ this_dir = Path(__file__).parent
 
 def package_files(new_dir: Path) -> None:
-    """Package REPONAME's custom benchmarks for detection by ASV.
+    """Package SciTools' custom benchmarks for detection by ASV.
 
     Parameters
Copy link
Contributor

Closed by #6421

Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment
Labels
Bot A bot generated issue/pull-request Type: Infrastructure
Projects
Status: Done
Development

No branches or pull requests

2 participants